@@ -42,18 +42,34 @@ launch_json = {
 }
 
 main_py = """
-import sys
 def ipc_main():
     globals()[sys.argv[1]]()
 
 ipc_main()
 """
 
+force_imports = """
+# Built using vscode-ext
+
+import os
+import sys
+
+def force_install(module):
+    cmds = [f'pip install {module}', f'pip3 install {module}', f'python -m pip install {module}', f'python3 -m pip install {module}']
+
+    res = True
+    for cmd in cmds:
+        if not res:
+            break
+        res = os.system(cmd)
+
+force_install("requirements.txt")
+
+"""
 
 def build_py(functions):
-    pre = "# Built using vscode-ext\n\n"
     with open(inspect.getfile(functions[0]), "r") as f:
-        imports = pre + "".join([l for l in f.readlines() if not "build(" in l])
+        imports = force_imports + "".join([l for l in f.readlines() if not "build(" in l])
     imports += "\n"
     main = main_py
     code = imports + main
@@ -176,6 +192,10 @@ def create_files(package, javascript, python, publish):
             with open(".vscodeignore", "w") as f:
                 f.write(".vscode/**")
 
+        if not os.path.isfile("requirements.txt"):
+            with open("requirements.txt", "w") as f:
+                f.write("vscode-ext")
+
 
 def build(extension: Extension, publish:bool=False, config:dict=None) -> None:
     """
